A dataset comprising lines from one or more text files.
text_line_dataset(filenames, compression_type = NULL, record_spec = NULL,
parallel_records = NULL)String(s) specifying one or more filenames
A string, one of: NULL (no compression), "ZLIB", or
"GZIP".
(Optional) Specification used to decode delimimted text lines
into records (see delim_record_spec()).
(Optional) An integer, representing the number of records to decode in parallel. If not specified, records will be processed sequentially.
A dataset